# coding=utf-8
from unittest import TestCase
from earthdiagnostics.box import Box


class TestBox(TestCase):

    def setUp(self):
        self.box1 = Box()
        self.box1.max_lat = 0
        self.box1.min_lat = -20
        self.box1.max_lon = 0
        self.box1.min_lon = -20
        self.box1.min_depth = 0
        self.box1.max_depth = 20

        self.box2 = Box(True)
        self.box2.max_lat = 20
        self.box2.min_lat = 20
        self.box2.max_lon = 20
        self.box2.min_lon = 20
        self.box2.min_depth = 20
        self.box2.max_depth = 20

        self.box3 = Box()

        self.box4 = Box()
        self.box4.max_lat = -10
        self.box4.min_lat = -20
        self.box4.max_lon = -10
        self.box4.min_lon = -20
        self.box4.min_depth = 0
        self.box4.max_depth = 20

    def test_max_lat(self):
        with self.assertRaises(ValueError):
            Box().max_lat = 100
        with self.assertRaises(ValueError):
            Box().max_lat = -100
        Box().max_lat = 0
        Box().max_lat = -20
        Box().max_lat = 20

    def test_min_lat(self):
        with self.assertRaises(ValueError):
            Box().min_lat = 100
        with self.assertRaises(ValueError):
            Box().min_lat = -100
        Box().min_lat = 0
        Box().min_lat = -90
        Box().min_lat = 90

    def test_max_lon(self):
        with self.assertRaises(ValueError):
            Box().max_lon = 360
        with self.assertRaises(ValueError):
            Box().max_lon = -360
        Box().max_lon = 0
        Box().max_lon = -20
        Box().max_lon = 20

    def test_min_lon(self):
        with self.assertRaises(ValueError):
            Box().min_lon = 360
        with self.assertRaises(ValueError):
            Box().min_lon = -360
        Box().min_lon = 0
        Box().min_lon = -80
        Box().min_lon = 80

    def test_get_lat_str(self):
        self.assertEquals('20S0N', self.box1.get_lat_str())
        self.assertEquals('20N', self.box2.get_lat_str())
        self.assertEquals('', self.box3.get_lat_str())
        self.assertEquals('20S10S', self.box4.get_lat_str())

    def test_get_lon_str(self):
        self.assertEquals('20W0E', self.box1.get_lon_str())
        self.assertEquals('20E', self.box2.get_lon_str())
        self.assertEquals('', self.box3.get_lon_str())
        self.assertEquals('20W10W', self.box4.get_lon_str())

    def test_get_depth_str(self):
        self.assertEquals('0-20', self.box1.get_depth_str())
        self.assertEquals('20m', self.box2.get_depth_str())
        self.assertEquals('', self.box3.get_depth_str())
        self.assertEquals('0-20', self.box4.get_depth_str())

    def test__str__(self):
        self.assertEquals('20S0N20W0E0-20', str(self.box1))
        self.assertEquals('20N20E20m', str(self.box2))
        self.assertEquals('', str(self.box3))
        self.assertEquals('20S10S20W10W0-20', str(self.box4))
