# coding=utf-8
from unittest import TestCase

from earthdiagnostics.statistics.climatologicalpercentile import ClimatologicalPercentile
from mock import Mock

from earthdiagnostics.modelingrealm import ModelingRealms


class TestClimatologicalPercentile(TestCase):

    def setUp(self):
        self.data_manager = Mock()
        self.data_manager.variable_list.get_variable.return_value = None

        self.diags = Mock()
        self.diags.data_manager = self.data_manager

        self.diagnostic = ClimatologicalPercentile(self.data_manager, ModelingRealms.ocean, 'var',
                                                   [10, 90], 1000, self.diags.config.experiment)

    def test_generate_jobs(self):
        jobs = ClimatologicalPercentile.generate_jobs(self.diags, ['climpercent', 'ocean', 'var', '1-2', '1000'])
        self.assertEqual(len(jobs), 1)
        self.assertEqual(jobs[0], ClimatologicalPercentile(self.data_manager, ModelingRealms.ocean, 'var', [1, 2],
                                                           1000, self.diags.config.experiment))

        with self.assertRaises(Exception):
            ClimatologicalPercentile.generate_jobs(self.diags, ['climpercent'])
        with self.assertRaises(Exception):
            ClimatologicalPercentile.generate_jobs(self.diags, ['climpercent', '0', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        self.assertEquals(str(self.diagnostic), 'Climatological percentile Variable: ocean:var Leadtimes: [10, 90] '
                                                'Bins: 1000')
