# coding=utf-8


from unittest import TestCase

from earthdiagnostics.datamanager import UnitConversion


class TestConversion(TestCase):

    def test__init(self):
        conversion = UnitConversion('km', 'm', 1000, 0)
        self.assertEqual(conversion.source, 'km')
        self.assertEqual(conversion.destiny, 'm')
        self.assertEqual(conversion.factor, 1000)
        self.assertEqual(conversion.offset, 0)

    def test_add_conversion(self):
        UnitConversion._dict_conversions = dict()
        conversion = UnitConversion('km', 'm', 1000, 0)
        UnitConversion.add_conversion(conversion)
        self.assertIs(UnitConversion._dict_conversions[('km', 'm')], conversion)
        UnitConversion._dict_conversions = dict()

    def test_get_factor_offset(self):
        UnitConversion._dict_conversions = dict()
        conversion = UnitConversion('km', 'm', 1000, 0)
        UnitConversion.add_conversion(conversion)
        self.assertEqual(UnitConversion.get_conversion_factor_offset('km', 'm'), (1000, 0))
        self.assertEqual(UnitConversion.get_conversion_factor_offset('m', 'km'), (1 / 1000.0, 0))
        self.assertEqual(UnitConversion.get_conversion_factor_offset('1e3 m', 'km'), (1, 0))
        self.assertEqual(UnitConversion.get_conversion_factor_offset('10^3 m', 'km'), (1, 0))
        self.assertEqual(UnitConversion.get_conversion_factor_offset('km', '1e3 m'), (1, 0))
        self.assertEqual(UnitConversion.get_conversion_factor_offset('km', '10^3 m'), (1, 0))
        self.assertEqual(UnitConversion.get_conversion_factor_offset('m', 'm'), (1, 0))
        self.assertEqual(UnitConversion.get_conversion_factor_offset('m²', 'km'), (None, None))

        UnitConversion._dict_conversions = dict()
