# coding=utf-8
from unittest import TestCase

from earthdiagnostics.frequency import Frequency
from earthdiagnostics.variable_type import VariableType


class TestFrequency(TestCase):

    def test_not_supported(self):
        with self.assertRaises(ValueError):
            Frequency('badfreq')

    def test_get_monthly_mean(self):
        self.assertEqual(Frequency('m').folder_name(VariableType.MEAN), 'monthly_mean')

    def test_get_monthly_stats(self):
        self.assertEqual(Frequency('m').folder_name(VariableType.STATISTIC), 'monthly_statistics')

    def test_get_daily_mean(self):
        self.assertEqual(Frequency('d').folder_name(VariableType.MEAN), 'daily_mean')

    def test_get_daily_stats(self):
        self.assertEqual(Frequency('d').folder_name(VariableType.STATISTIC), 'daily_statistics')

    def test_get_6hourlymean(self):
        self.assertEqual(Frequency('6hr').folder_name(VariableType.STATISTIC), '6hourly')

    def test_get_climatology(self):
        self.assertEqual(Frequency('clim').folder_name(VariableType.STATISTIC), 'clim')
        self.assertEqual(Frequency('clim').folder_name(VariableType.MEAN), 'clim')

