# coding=utf-8
from unittest import TestCase

from earthdiagnostics.box import Box
from earthdiagnostics.constants import Basins
from earthdiagnostics.ocean.heatcontent import HeatContent
from mock import Mock


class TestHeatContent(TestCase):

    def setUp(self):
        self.data_manager = Mock()

        self.diags = Mock()
        self.diags.model_version = 'model_version'
        self.diags.config.experiment.get_chunk_list.return_value = (('20010101', 0, 0), ('20010101', 0, 1))

        self.box = Box(False)
        self.box.min_depth = 0
        self.box.max_depth = 100

        self.heat_content = HeatContent(self.data_manager, '20000101', 1, 1, Basins.Global, 1, self.box)

    def test_generate_jobs(self):
        jobs = HeatContent.generate_jobs(self.diags, ['diagnostic', 'atl', '-1', '0', '100'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], HeatContent(self.data_manager, '20010101', 0, 0, Basins.Atlantic, -1, self.box))
        self.assertEqual(jobs[1], HeatContent(self.data_manager, '20010101', 0, 1, Basins.Atlantic, -1, self.box))

        with self.assertRaises(Exception):
            HeatContent.generate_jobs(self.diags, ['diagnostic'])

        with self.assertRaises(Exception):
            HeatContent.generate_jobs(self.diags, ['diagnostic', '0', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        self.assertEquals(str(self.heat_content), 'Heat content Startdate: 20000101 Member: 1 Chunk: 1 Mixed layer: 1 '
                                                  'Box: 0-100 Basin: Global_Ocean')
