# coding=utf-8
from unittest import TestCase

from earthdiagnostics.box import Box
from earthdiagnostics.frequency import Frequencies
from earthdiagnostics.general.monthlymean import MonthlyMean
from mock import Mock

from earthdiagnostics.modelingrealm import ModelingRealms


class TestMonthlyMean(TestCase):

    def setUp(self):
        self.data_manager = Mock()

        self.diags = Mock()
        self.diags.model_version = 'model_version'
        self.diags.config.experiment.get_chunk_list.return_value = (('20010101', 0, 0), ('20010101', 0, 1))

        self.box = Box()
        self.box.min_depth = 0
        self.box.max_depth = 100

        self.mixed = MonthlyMean(self.data_manager, '20000101', 1, 1, ModelingRealms.ocean, 'var', 'freq', '')

    def test_generate_jobs(self):

        jobs = MonthlyMean.generate_jobs(self.diags, ['diagnostic', 'var', 'ocean'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], MonthlyMean(self.data_manager, '20010101', 0, 0, ModelingRealms.ocean, 'var',
                                              Frequencies.daily, ''))
        self.assertEqual(jobs[1], MonthlyMean(self.data_manager, '20010101', 0, 1, ModelingRealms.ocean, 'var',
                                              Frequencies.daily, ''))

        jobs = MonthlyMean.generate_jobs(self.diags, ['diagnostic', 'var', 'atmos', 'monthly'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], MonthlyMean(self.data_manager, '20010101', 0, 0, ModelingRealms.atmos, 'var',
                                              Frequencies.monthly, ''))
        self.assertEqual(jobs[1], MonthlyMean(self.data_manager, '20010101', 0, 1, ModelingRealms.atmos, 'var',
                                              Frequencies.monthly, ''))

        jobs = MonthlyMean.generate_jobs(self.diags, ['diagnostic', 'var', 'seaice', 'mon', 'grid'])
        self.assertEqual(len(jobs), 2)
        self.assertEqual(jobs[0], MonthlyMean(self.data_manager, '20010101', 0, 0, ModelingRealms.seaIce, 'var',
                                              Frequencies.monthly, 'grid'))
        self.assertEqual(jobs[1], MonthlyMean(self.data_manager, '20010101', 0, 1, ModelingRealms.seaIce, 'var',
                                              Frequencies.monthly, 'grid'))

        with self.assertRaises(Exception):
            MonthlyMean.generate_jobs(self.diags, ['diagnostic'])

        with self.assertRaises(Exception):
            MonthlyMean.generate_jobs(self.diags, ['diagnostic', '0', '0', '0', '0', '0', '0', '0'])

    def test_str(self):
        self.assertEquals(str(self.mixed), 'Calculate monthly mean Startdate: 20000101 Member: 1 Chunk: 1 '
                                           'Variable: ocean:var')
